# {{ ansible_managed }}
[uwsgi]
master = true
processes = 2
threads = 2
plugin = python3
no-orphans = true
chmod-socket = 660
{% if uwsgi_venv is defined and uwsgi_venv | length > 0 %}
virtualenv = {{ uwsgi_venv }}
{% endif %}

socket = /run/uwsgi/keystone-public.socket
pidfile = /run/uwsgi/keystone-public.pid

name = keystone
uid = keystone
gid = {{ nginx_user }}

chdir = /var/www/keystone/
wsgi-file = /var/www/keystone/public
