# {{ ansible_managed }}
server {
    listen 5000;
    access_log /var/log/nginx/keystone/access.log;
    error_log /var/log/nginx/keystone/error.log;
    location / {
        uwsgi_pass unix:///run/uwsgi/keystone-public.socket;
        include uwsgi_params;
        uwsgi_param SCRIPT_NAME '';
    }
}
server {
    listen 35357;
    access_log /var/log/nginx/keystone/access.log;
    error_log /var/log/nginx/keystone/error.log;
    location / {
        uwsgi_pass unix:///run/uwsgi/keystone-admin.socket;
        include uwsgi_params;
        uwsgi_param SCRIPT_NAME '';
   }
}
